@@ -10,15 +10,15 @@ ENDPOINTS = {
     "MARKET_BOOKS_PATH": "/api/market/books?sym={sym}&lmt={lmt}",
     "MARKET_TRADING_VIEW_PATH": "/api/market/tradingview?sym={sym}&int={int}&frm={frm}&to={to}",
     "MARKET_DEPTH_PATH": "/api/market/depth?sym={sym}&lmt={lmt}",
-    "MARKET_WALLET": "/api/merket/wallet",
-    "MARKET_BALANCES": "/api/merket/balances",
-    "MARKET_PLACE_BID": "/api/merket/place-bid",
-    "MARKET_PLACE_ASK": "/api/merket/place-ask",
-    "MARKET_PLACE_ASK_BY_FIAT": "/api/merket/place-ask-by-fiat",
-    "MARKET_CANCEL_ORDER": "/api/merket/cancel-order",
-    "MARKET_MY_OPEN_ORDERS": "/api/merket/my-open-orders",
-    "MARKET_MY_ORDER_HISTORY": "/api/merket/my-order-history",
-    "MARKET_ORDER_INFO": "/api/merket/order-info",
+    "MARKET_WALLET": "/api/market/wallet",
+    "MARKET_BALANCES": "/api/market/balances",
+    "MARKET_PLACE_BID": "/api/market/place-bid",
+    "MARKET_PLACE_ASK": "/api/market/place-ask",
+    "MARKET_PLACE_ASK_BY_FIAT": "/api/market/place-ask-by-fiat",
+    "MARKET_CANCEL_ORDER": "/api/market/cancel-order",
+    "MARKET_MY_OPEN_ORDERS": "/api/market/my-open-orders",
+    "MARKET_MY_ORDER_HISTORY": "/api/market/my-order-history",
+    "MARKET_ORDER_INFO": "/api/market/order-info",
     "CRYPTO_ADDRESSES": "/api/crypto/addresses",
     "CRYPTO_WITHDRAW": "/api/crypto/withdraw",
     "CRYPTO_DEPOSIT_HISTORY": "/api/crypto/deposit-history",
@@ -27,7 +27,7 @@ ENDPOINTS = {
     "FIAT_WITHDRAW": "/api/fiat/withdraw",
     "FIAT_DEPOSIT_HISTORY": "/api/fiat/deposit-history",
     "FIAT_WITHDRAW_HISTORY": "/api/fiat/withdraw-history",
-    "MARKET_WSTOKEN": "/api/merket/wstoken",
+    "MARKET_WSTOKEN": "/api/market/wstoken",
     "USER_LIMITS": "/api/user/limits",
     "USER_TRADING_CREDITS": "/api/user/trading-credits",
 }
